package edu.mit.harold.icollections.tests;

import java.util.LinkedList;
import java.util.List;
import java.util.Random;

import edu.mit.harold.icollections.ConsIStack;
import edu.mit.harold.icollections.IStack;

import junit.framework.TestCase;

public class ConsIStackTest extends TestCase {
	
	/**
	 * Compares the behavior of java.util.LinkedList to the behavior of ConsIStack.
	 */
	public void testRandomlyAgainstJavaList() {
		IStack<Integer> istack = ConsIStack.empty();
		List<Integer> list = new LinkedList<Integer>();
		Random r = new Random();
		for(int i=0;i<1000;i++) {
			if(istack.size()==0 || r.nextBoolean()) { // add
				if(r.nextBoolean()) { // append
					Integer v = r.nextInt();
		
					assertEquals(list.contains(v), istack.contains(v));
					
					list.add(0,v);
					istack = istack.plus(v);
				}
				else { // insert
					int k = r.nextInt(istack.size()+1);
					Integer v = r.nextInt();
	
					assertEquals(list.contains(v), istack.contains(v));
					if(k<istack.size())
						assertEquals(list.get(k), istack.get(k));
	
					list.add(k, v);
					istack = istack.plus(k, v);
				}
			}
			else if(r.nextBoolean()) { // replace
				int k = r.nextInt(istack.size());
				Integer v = r.nextInt();
				list.set(k, v);
				istack = istack.with(k, v);
			}
			else { // remove a random element
				int j = r.nextInt(istack.size()), k=0;
				for(Integer e : istack) {

					assertTrue(list.contains(e));
					assertTrue(istack.contains(e));
					assertEquals(e, istack.get(k));
					assertEquals(list.get(k), istack.get(k));
					UtilityTest.assertEqualsAndHash( istack, istack.minus(k).plus(k, istack.get(k)) );
					UtilityTest.assertEqualsAndHash( istack, istack.plus(k, 10).minus(k) );

					if(k==j) {
						list.remove(k);
						istack = istack.minus(k);
						k--; // indices are now smaller
						j = -1; // don't remove again
					}
					k++;
				}
			}
			
			// also try to remove a _totally_ random value:
			Integer v = r.nextInt();
			assertEquals(list.contains(v), istack.contains(v));
			list.remove(v);
			istack = istack.minus(v);
			
			// and try out a non-Integer:
			String s = Integer.toString(v);
			assertFalse( istack.contains(v) );
			istack = istack.minus(s);

			assertEquals(list.size(), istack.size());
			UtilityTest.assertEqualsAndHash(list, istack);
			
			UtilityTest.assertEqualsAndHash(istack, ConsIStack.from(istack));
			UtilityTest.assertEqualsAndHash(ConsIStack.empty(), istack.minusAll(istack));
			UtilityTest.assertEqualsAndHash(istack,
					ConsIStack.empty().plusAll(UtilityTest.reverse(istack)));
			UtilityTest.assertEqualsAndHash(istack,
					ConsIStack.singleton(10).plusAll(1,UtilityTest.reverse(istack)).minus(0));
		}
	}

	public void testSubListIntInt() {
		// TODO
	}

	public void testMinusObject() {
		// TODO
	}

}
